@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -27,7 +27,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateAccessGroup(self, request):
-        """创建权限组。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        创建权限组。
 
         :param request: Request instance for CreateAccessGroup.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateAccessGroupRequest`
@@ -36,17 +38,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAccessGroup", params)
+            headers = request.headers
+            body = self.call("CreateAccessGroup", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateAccessGroupResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateAccessGroupResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -55,7 +52,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateAccessRules(self, request):
-        """批量创建权限规则，权限规则ID和创建时间无需填写。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量创建权限规则，权限规则ID和创建时间无需填写。
 
         :param request: Request instance for CreateAccessRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateAccessRulesRequest`
@@ -64,17 +63,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateAccessRules", params)
+            headers = request.headers
+            body = self.call("CreateAccessRules", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateAccessRulesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateAccessRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -83,7 +77,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateFileSystem(self, request):
-        """创建文件系统（异步）。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        创建文件系统（异步）。
 
         :param request: Request instance for CreateFileSystem.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateFileSystemRequest`
@@ -92,17 +88,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateFileSystem", params)
+            headers = request.headers
+            body = self.call("CreateFileSystem", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateFileSystemResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateFileSystemResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -111,7 +102,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateLifeCycleRules(self, request):
-        """批量创建生命周期规则，生命周期规则ID和创建时间无需填写。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量创建生命周期规则，生命周期规则ID和创建时间无需填写。
 
         :param request: Request instance for CreateLifeCycleRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateLifeCycleRulesRequest`
@@ -120,17 +113,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateLifeCycleRules", params)
+            headers = request.headers
+            body = self.call("CreateLifeCycleRules", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateLifeCycleRulesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateLifeCycleRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -139,7 +127,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateMountPoint(self, request):
-        """创建文件系统挂载点，仅限于创建成功的文件系统。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        创建文件系统挂载点，仅限于创建成功的文件系统。
 
         :param request: Request instance for CreateMountPoint.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateMountPointRequest`
@@ -148,17 +138,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateMountPoint", params)
+            headers = request.headers
+            body = self.call("CreateMountPoint", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateMountPointResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateMountPointResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -167,7 +152,9 @@ class ChdfsClient(AbstractClient):
 
 
     def CreateRestoreTasks(self, request):
-        """批量创建回热任务，回热任务ID、状态和创建时间无需填写。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量创建回热任务，回热任务ID、状态和创建时间无需填写。
 
         :param request: Request instance for CreateRestoreTasks.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.CreateRestoreTasksRequest`
@@ -176,17 +163,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateRestoreTasks", params)
+            headers = request.headers
+            body = self.call("CreateRestoreTasks", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.CreateRestoreTasksResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.CreateRestoreTasksResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -195,7 +177,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DeleteAccessGroup(self, request):
-        """删除权限组。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        删除权限组。
 
         :param request: Request instance for DeleteAccessGroup.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DeleteAccessGroupRequest`
@@ -204,17 +188,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAccessGroup", params)
+            headers = request.headers
+            body = self.call("DeleteAccessGroup", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteAccessGroupResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DeleteAccessGroupResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -223,7 +202,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DeleteAccessRules(self, request):
-        """批量删除权限规则。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量删除权限规则。
 
         :param request: Request instance for DeleteAccessRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DeleteAccessRulesRequest`
@@ -232,17 +213,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteAccessRules", params)
+            headers = request.headers
+            body = self.call("DeleteAccessRules", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteAccessRulesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DeleteAccessRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -251,7 +227,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DeleteFileSystem(self, request):
-        """删除文件系统，不允许删除非空文件系统。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        删除文件系统，不允许删除非空文件系统。
 
         :param request: Request instance for DeleteFileSystem.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DeleteFileSystemRequest`
@@ -260,17 +238,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteFileSystem", params)
+            headers = request.headers
+            body = self.call("DeleteFileSystem", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteFileSystemResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DeleteFileSystemResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -279,7 +252,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DeleteLifeCycleRules(self, request):
-        """批量删除生命周期规则。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量删除生命周期规则。
 
         :param request: Request instance for DeleteLifeCycleRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DeleteLifeCycleRulesRequest`
@@ -288,17 +263,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteLifeCycleRules", params)
+            headers = request.headers
+            body = self.call("DeleteLifeCycleRules", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteLifeCycleRulesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DeleteLifeCycleRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -307,7 +277,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DeleteMountPoint(self, request):
-        """删除挂载点。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        删除挂载点。
 
         :param request: Request instance for DeleteMountPoint.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DeleteMountPointRequest`
@@ -316,17 +288,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteMountPoint", params)
+            headers = request.headers
+            body = self.call("DeleteMountPoint", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DeleteMountPointResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DeleteMountPointResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -335,7 +302,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeAccessGroups(self, request):
-        """查看权限组列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        查看权限组列表。
 
         :param request: Request instance for DescribeAccessGroups.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeAccessGroupsRequest`
@@ -344,17 +313,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccessGroups", params)
+            headers = request.headers
+            body = self.call("DescribeAccessGroups", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAccessGroupsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeAccessGroupsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -363,7 +327,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeAccessRules(self, request):
-        """通过权限组ID查看权限规则列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        通过权限组ID查看权限规则列表。
 
         :param request: Request instance for DescribeAccessRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeAccessRulesRequest`
@@ -372,17 +338,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeAccessRules", params)
+            headers = request.headers
+            body = self.call("DescribeAccessRules", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeAccessRulesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeAccessRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -391,7 +352,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeFileSystem(self, request):
-        """查看文件系统详细信息。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        查看文件系统详细信息。
 
         :param request: Request instance for DescribeFileSystem.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeFileSystemRequest`
@@ -400,17 +363,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFileSystem", params)
+            headers = request.headers
+            body = self.call("DescribeFileSystem", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeFileSystemResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeFileSystemResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -419,7 +377,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeFileSystems(self, request):
-        """查看文件系统列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        查看文件系统列表。
 
         :param request: Request instance for DescribeFileSystems.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeFileSystemsRequest`
@@ -428,17 +388,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeFileSystems", params)
+            headers = request.headers
+            body = self.call("DescribeFileSystems", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeFileSystemsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeFileSystemsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -447,7 +402,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeLifeCycleRules(self, request):
-        """通过文件系统ID查看生命周期规则列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        通过文件系统ID查看生命周期规则列表。
 
         :param request: Request instance for DescribeLifeCycleRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeLifeCycleRulesRequest`
@@ -456,17 +413,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeLifeCycleRules", params)
+            headers = request.headers
+            body = self.call("DescribeLifeCycleRules", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeLifeCycleRulesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeLifeCycleRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -475,7 +427,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeMountPoint(self, request):
-        """查看挂载点详细信息。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        查看挂载点详细信息。
 
         :param request: Request instance for DescribeMountPoint.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeMountPointRequest`
@@ -484,17 +438,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMountPoint", params)
+            headers = request.headers
+            body = self.call("DescribeMountPoint", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeMountPointResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeMountPointResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -503,7 +452,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeMountPoints(self, request):
-        """通过文件系统ID或者权限组ID查看挂载点列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        通过文件系统ID或者权限组ID查看挂载点列表。
 
         :param request: Request instance for DescribeMountPoints.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeMountPointsRequest`
@@ -512,17 +463,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeMountPoints", params)
+            headers = request.headers
+            body = self.call("DescribeMountPoints", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeMountPointsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeMountPointsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -531,7 +477,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeResourceTags(self, request):
-        """通过文件系统ID查看资源标签列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        通过文件系统ID查看资源标签列表。
 
         :param request: Request instance for DescribeResourceTags.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeResourceTagsRequest`
@@ -540,17 +488,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeResourceTags", params)
+            headers = request.headers
+            body = self.call("DescribeResourceTags", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeResourceTagsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeResourceTagsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -559,7 +502,9 @@ class ChdfsClient(AbstractClient):
 
 
     def DescribeRestoreTasks(self, request):
-        """通过文件系统ID查看回热任务列表。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        通过文件系统ID查看回热任务列表。
 
         :param request: Request instance for DescribeRestoreTasks.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.DescribeRestoreTasksRequest`
@@ -568,17 +513,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DescribeRestoreTasks", params)
+            headers = request.headers
+            body = self.call("DescribeRestoreTasks", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.DescribeRestoreTasksResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.DescribeRestoreTasksResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -587,7 +527,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyAccessGroup(self, request):
-        """修改权限组属性。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        修改权限组属性。
 
         :param request: Request instance for ModifyAccessGroup.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyAccessGroupRequest`
@@ -596,17 +538,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAccessGroup", params)
+            headers = request.headers
+            body = self.call("ModifyAccessGroup", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.ModifyAccessGroupResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.ModifyAccessGroupResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -615,7 +552,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyAccessRules(self, request):
-        """批量修改权限规则属性，需要指定权限规则ID，支持修改权限规则地址、访问模式和优先级。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量修改权限规则属性，需要指定权限规则ID，支持修改权限规则地址、访问模式和优先级。
 
         :param request: Request instance for ModifyAccessRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyAccessRulesRequest`
@@ -624,17 +563,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyAccessRules", params)
+            headers = request.headers
+            body = self.call("ModifyAccessRules", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.ModifyAccessRulesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.ModifyAccessRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -643,7 +577,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyFileSystem(self, request):
-        """修改文件系统属性，仅限于创建成功的文件系统。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        修改文件系统属性，仅限于创建成功的文件系统。
 
         :param request: Request instance for ModifyFileSystem.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyFileSystemRequest`
@@ -652,17 +588,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyFileSystem", params)
+            headers = request.headers
+            body = self.call("ModifyFileSystem", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.ModifyFileSystemResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.ModifyFileSystemResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -671,7 +602,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyLifeCycleRules(self, request):
-        """批量修改生命周期规则属性，需要指定生命周期规则ID，支持修改生命周期规则名称、路径、转换列表和状态。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        批量修改生命周期规则属性，需要指定生命周期规则ID，支持修改生命周期规则名称、路径、转换列表和状态。
 
         :param request: Request instance for ModifyLifeCycleRules.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyLifeCycleRulesRequest`
@@ -680,17 +613,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyLifeCycleRules", params)
+            headers = request.headers
+            body = self.call("ModifyLifeCycleRules", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.ModifyLifeCycleRulesResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.ModifyLifeCycleRulesResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -699,7 +627,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyMountPoint(self, request):
-        """修改挂载点属性。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        修改挂载点属性。
 
         :param request: Request instance for ModifyMountPoint.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyMountPointRequest`
@@ -708,17 +638,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyMountPoint", params)
+            headers = request.headers
+            body = self.call("ModifyMountPoint", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.ModifyMountPointResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.ModifyMountPointResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
@@ -727,7 +652,9 @@ class ChdfsClient(AbstractClient):
 
 
     def ModifyResourceTags(self, request):
-        """修改资源标签列表，全量覆盖。
+        """云API旧版本2019-07-18预下线，所有功能由新版本2020-11-12替代，目前云API主要用作控制台使用。
+
+        修改资源标签列表，全量覆盖。
 
         :param request: Request instance for ModifyResourceTags.
         :type request: :class:`tencentcloud.chdfs.v20190718.models.ModifyResourceTagsRequest`
@@ -736,17 +663,12 @@ class ChdfsClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ModifyResourceTags", params)
+            headers = request.headers
+            body = self.call("ModifyResourceTags", params, headers=headers)
             response = json.loads(body)
-            if "Error" not in response["Response"]:
-                model = models.ModifyResourceTagsResponse()
-                model._deserialize(response["Response"])
-                return model
-            else:
-                code = response["Response"]["Error"]["Code"]
-                message = response["Response"]["Error"]["Message"]
-                reqid = response["Response"]["RequestId"]
-                raise TencentCloudSDKException(code, message, reqid)
+            model = models.ModifyResourceTagsResponse()
+            model._deserialize(response["Response"])
+            return model
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
